==> lxqt-l10n_0.11.1.orig.tar.xz: lxqt-l10n-0.11.1/lxqt-panel/plugin-kbindicator/kbindicator_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>Content</name>
    <message>
        <location filename="../../../src/content.cpp" line="43"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="46"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation>CapsLock</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="50"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="52"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation>NumLock</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="57"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="59"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation>ScrollLock</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="90"/>
        <source>Layout</source>
        <translation>Διάταξη</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="90"/>
        <source>Variant</source>
        <translation>Παραλλαγή</translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <source>Dialog</source>
        <translation>Διάλογος</translation>
    </message>
    <message>
        <source>Leds</source>
        <translation>Φωτεινοί δίοδοι</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>Εμφάνιση του κλειδώματος κεφαλαίων</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>Εμφάνιση του κλειδώματος του αριθμητικού πληκτρολογίου</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>Εμφάνιση του κλειδώματος της κύλισης</translation>
    </message>
    <message>
        <source>Show keyboard layout</source>
        <translation>Εμφάνιση της διάταξης του πληκτρολογίου</translation>
    </message>
    <message>
        <source>Show flags instead labels</source>
        <translation>Εμφάνιση της σημαίας αντί της ετικέτας</translation>
    </message>
    <message>
        <source>Layout mode:</source>
        <translation>Λειτουργία της διάταξης:</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>Ρυθμίσεις κατάστασης του πληκτρολογίου</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>Δείκτες κλειδώματος</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>Δείκτης διάταξης του πληκτρολογίου</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>Πολιτική εναλλαγής</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>Καθολικό</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>Παράθυρο</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="102"/>
        <source>Configure layouts</source>
        <translation>Διαμόρφωση των διατάξεων</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-panel/plugin-kbindicator/kbindicator_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>Content</name>
    <message>
        <location filename="../../../src/content.cpp" line="43"/>
        <source>C</source>
        <comment>Label for CapsLock indicator</comment>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="46"/>
        <source>CapsLock</source>
        <comment>Tooltip for CapsLock indicator</comment>
        <translation>CapsLock</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="50"/>
        <source>N</source>
        <comment>Label for NumLock indicator</comment>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="52"/>
        <source>NumLock</source>
        <comment>Tooltip for NumLock indicator</comment>
        <translation>NumLock</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="57"/>
        <source>S</source>
        <comment>Label for ScrollLock indicator</comment>
        <translation>S</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="59"/>
        <source>ScrollLock</source>
        <comment>Tooltip for ScrollLock indicator</comment>
        <translation>ScrollLock</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="90"/>
        <source>Layout</source>
        <translation>Διάταξη</translation>
    </message>
    <message>
        <location filename="../../../src/content.cpp" line="90"/>
        <source>Variant</source>
        <translation>Παραλλαγή</translation>
    </message>
</context>
<context>
    <name>KbdStateConfig</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">Διάλογος</translation>
    </message>
    <message>
        <source>Leds</source>
        <translation type="vanished">Φωτεινοί δίοδοι</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="26"/>
        <source>Show Caps Lock</source>
        <translation>Εμφάνιση του κλειδώματος κεφαλαίων</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="33"/>
        <source>Show Num Lock</source>
        <translation>Εμφάνιση του κλειδώματος του αριθμητικού πληκτρολογίου</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="40"/>
        <source>Show Scroll Lock</source>
        <translation>Εμφάνιση του κλειδώματος της κύλισης</translation>
    </message>
    <message>
        <source>Show keyboard layout</source>
        <translation type="vanished">Εμφάνιση της διάταξης του πληκτρολογίου</translation>
    </message>
    <message>
        <source>Show flags instead labels</source>
        <translation type="vanished">Εμφάνιση της σημαίας αντί της ετικέτας</translation>
    </message>
    <message>
        <source>Layout mode:</source>
        <translation type="vanished">Λειτουργία της διάταξης:</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="14"/>
        <source>Keyboard state settings</source>
        <translation>Ρυθμίσεις κατάστασης του πληκτρολογίου</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="20"/>
        <source>Lock Indicators</source>
        <translation>Δείκτες κλειδώματος</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="50"/>
        <source>Keyboard Layout Indicator</source>
        <translation>Δείκτης διάταξης του πληκτρολογίου</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="62"/>
        <source>Switching policy</source>
        <translation>Πολιτική εναλλαγής</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="69"/>
        <source>Global</source>
        <translation>Καθολικό</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="79"/>
        <source>Window</source>
        <translation>Παράθυρο</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="89"/>
        <source>Application</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../../../src/kbdstateconfig.ui" line="102"/>
        <source>Configure layouts</source>
        <translation>Διαμόρφωση των διατάξεων</translation>
    </message>
</context>
</TS>
